<fieldset class="aa-discord-ping-formatter-form">
    <div class="form-group clearfix">
        <label class="col-md-3 control-label" for="pingType">Ping Type</label>
        <div class="col-md-9">
            <select id="pingType" name="pingType" class="form-control">
                <option value="@here">@here</option>
                <option value="@everyone">@everyone</option>
            </select>
        </div>
    </div>

    <div class="form-group clearfix">
        <div class="col-md-3">&nbsp;</div>
        <div class="col-md-9">
            <div class="checkbox">
                <label for="prePing">
                    <input type="checkbox" name="prePing" id="prePing" value="1"> Pre-Ping
                </label>
            </div>
        </div>
    </div>

    <div class="form-group clearfix">
        <label class="col-md-3 control-label" for="fleetType">Fleet Type</label>
        <div class="col-md-9">
            <select id="fleetType" name="fleetType" class="form-control">
                <option value="">Please select</option>
                <option value="Roaming">Roam</option>
                <option value="Home Defense">Home Defense</option>
                <option value="StratOP">StratOP</option>
                <option value="CTA">CTA</option>
            </select>
        </div>
    </div>

    <div class="form-group clearfix">
        <label class="col-md-3 control-label" for="fcName">FC Name</label>
        <div class="col-md-9">
            <input id="fcName" name="fcName" type="text" class="form-control input-md" required="">
        </div>
    </div>

    <div class="form-group clearfix">
        <label class="col-md-3 control-label" for="fleetName">Fleet Name</label>
        <div class="col-md-9">
            <input id="fleetName" name="fleetName" type="text" class="form-control input-md" required="">
        </div>
    </div>

    <div class="form-group clearfix">
        <label class="col-md-3 control-label" for="formupLocation">Formup Location</label>
        <div class="col-md-9">
            <input id="formupLocation" name="formupLocation" type="text" class="form-control input-md" required="">
        </div>
    </div>

    <div class="form-group clearfix">
        <label class="col-md-3 control-label" for="formupTime">Formup Time</label>
        <div class="col-md-9">
            <input id="formupTime" name="formupTime" type="text" class="form-control input-md" required="">
        </div>
    </div>

    <div class="form-group clearfix">
        <label class="col-md-3 control-label" for="fleetComms">Fleet Comms</label>
        <div class="col-md-9">
            <input id="fleetComms" name="fleetComms" type="text" class="form-control input-md" required="">
        </div>
    </div>

    <div class="form-group clearfix">
        <label class="col-md-3 control-label" for="fleetDoctrine">Ships / Doctrine</label>
        <div class="col-md-9">
            <input id="fleetDoctrine" name="fleetDoctrine" type="text" class="form-control input-md" required="">
        </div>
    </div>

    <div class="form-group clearfix">
        <label class="col-md-3 control-label" for="fleetSrp">SRP</label>
        <div class="col-md-9">
            <select id="fleetSrp" name="fleetSrp" class="form-control">
                <option value="">Please select</option>
                <option value="Yes">Yes</option>
                <option value="No">No</option>
            </select>
        </div>
    </div>

    <div class="form-group clearfix">
        <label class="col-md-3 control-label" for="additinalInformation">Additional Information</label>
        <div class="col-md-9">
            <textarea class="form-control" id="additinalInformation" name="additinalInformation" rows="7"></textarea>
        </div>
    </div>

    <div class="form-group clearfix">
        <label class="col-md-3 control-label" for="createPingText"></label>
        <div class="col-md-4">
            <button id="createPingText" name="createPingText" class="btn btn-primary">Create Discord Ping Text</button>
        </div>
    </div>
</fieldset>
