<div class="aa-discord-ping-formatter-ping" style="display: none;">
    <div class="aa-discord-ping-formatter-ping-header">
        <p><b>Discord Formatted Text</b></p>
    </div>

    <div class="aa-discord-ping-formatter-ping-text"></div>

    <div class="aa-discord-ping-formatter-ping-copyresult"></div>

    <div class="form-group clearfix">
        <p><button id="copyDiscordPing" name="copyDiscordPing" class="btn btn-primary" data-clipboard-action="copy" data-clipboard-target=".aa-discord-ping-formatter-ping-text">Copy Ping</button></p>
    </div>
</div>
